# AgentLocalAuthInfo

Configuration for the agent when performing local authentication

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**org_id** | **str** | Unique identifier | 
**local_authentication_public_key** | **str** | A PEM encoded key that is used by clients to sign authentication credentials submitted to the agent when performing local authentication. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


